/*
 ***********************************************************************************************************************
 *
 * Copyright (c) Infineon Technologies AG
 * All rights reserved.
 *
 * The applicable license agreement can be found at this pack's installation directory in the file
 * license/IFX_SW_Licence_MOTIX_LITIX.txt
 *
 **********************************************************************************************************************/

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** AA          Abhilash Abhilash                                              **
** CK          Chander Kumar                                                  **
** JO           Julia Ott                                                     **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V0.1.0: 2020-09-23, AA: EP-926:  Initial version                           **
** V0.1.1: 2022-07-28, CK: EP-926: Modified for compilation with both ARMCC   **
**                         v5.06 and v6.16                                    **
** V0.1.2: 2024-10-04, JO:   EP-1494: Updated license                         **
*******************************************************************************/


#ifndef _AES_GCM_H_
#define _AES_GCM_H_

/*******************************************************************************
**                                  Includes                                  **
*******************************************************************************/
#include "types.h"
#include "bootrom.h"

/*******************************************************************************
**                          Global Type Declarations                          **
*******************************************************************************/

/** \struct tAesGcm
 *  \brief This struct lists the parameters for the Galois Counter Mode operation 
 */
typedef struct AesGcm
{
  user_crypto_inp_buf_t s_inp;
  user_crypto_inp_buf_t s_iv;
  user_crypto_inp_buf_t s_out;
  uint8 u8_tag[16];
  user_crypto_inp_buf_t s_aad;
  uint8 u8_hashKey[16];
  uint8 u8_gHash[16];
}tAesGcm;

/*******************************************************************************
**                          Global Macro Declarations                         **
*******************************************************************************/
/** \brief  IO buffer size  */ 
#define TLE989X_IO_BUFFER_SIZE  (60u)

/** \brief Encrypt data length  at once  */
#define ENCRYPT_DATA_LENGTH (16u)


/** \brief Encrypt data length  at once  */
#define AAD_LENGTH  (20u)


/** \brief Memset value  */
#define MEMSET_ZERO (0u)

/** \brief Initialization vector value  */
#define GCM_DEFAULT_IV_LENGTH (12u)

/** \brief Concatenated data length  */
#define CONCATENATED_LENGTH (2u)

/** \brief Bit0  */
#define BIT_MASK0 (0x01u)

/** \brief Bit1  */
#define BIT_MASK1 (0x02u)

/** \brief Bit2  */
#define BIT_MASK2 (0x04u)

/** \brief Bit3  */
#define BIT_MASK3 (0x08u)

/** \brief Bit4  */
#define BIT_MASK4 (0x10u)

/** \brief Bit5  */
#define BIT_MASK5 (0x20u)

/** \brief Bit6  */
#define BIT_MASK6 (0x40u)

/** \brief Bit7  */
#define BIT_MASK7 (0x80u)

/** \brief Update length used for encrption or decryption  */
#define AES_UPDATE_LENGTH (32u)      

/**  \brief Key slot to be used for Encryption. Note: Key slot '0' is Reserved. */
#define KEY_ID (1u)

/*******************************************************************************
**                        Global Function Declarations                        **
*******************************************************************************/
sint32 encryptOperationGCM(tAesGcm *sp_ctx);




#endif  /* _AES_GCM_H_  */



