/*
 ***********************************************************************************************************************
 *
 * Copyright (c) Infineon Technologies AG
 * All rights reserved.
 *
 * The applicable license agreement can be found at this pack's installation directory in the file
 * license/IFX_SW_Licence_MOTIX_LITIX.txt
 *
 **********************************************************************************************************************/

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** JO           Julia Ott                                                     **
** CK           Chander Kumar                                                 **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V1.0.0: 2022-08-25, JO, CK: EP-1243: Initial version of application        **
** V1.1.0: 2023-04-18, JO:     EP-1235: Changed to C startup file             **
** V1.2.0: 2024-06-14, JO:     EP-1480: Disabled warning 'unsafe buffer usage'**
**                             (ARM compiler for Embedded version >6.21)      **
** V1.2.1: 2024-10-04, JO:     EP-1494: Updated license                       **
** V1.3.0: 2024-12-04, JO:   EP-1553: Add all drivers to the example in RTE   **
*******************************************************************************/

/*******************************************************************************
**                                  Abstract                                  **
********************************************************************************
** Application example                                                        **
********************************************************************************
** Flash both Bootloader and Application example to the chip.                 **
** Bootloader toggels P0.1.                                                   **
** On MON1 press, the Bootloader jumps to the application (P0.1 not toggled   **
** anymore).                                                                  **
** Application toggels P0.2.                                                  **
*******************************************************************************/

/*******************************************************************************
**                                  Includes                                  **
*******************************************************************************/
#include "tle_device.h"
#include "types.h"
#include "gpio.h"

/*******************************************************************************
**                           Function Declarations                            **
*******************************************************************************/
void MON2_RI_Int(void);


sint32 main(void)
{
  sint8 s8_returnCode;
  uint32 u32_tick = 0;
  
  /* Enable all interrupts that are disbaled by BL before jump to application */
  __enable_irq();
  
   /* Main watchdog service */
   /* Service watchdog by toggling bit PMU->WD_TRIG.bit.TRIG to close the SOW opened in the BL */
   PMU->WD_TRIG.bit.TRIG ^= 1u;

  /* Initialization of hardware modules based on Config Wizard configuration */
  s8_returnCode = TLE_init();
  
  if (s8_returnCode != ERR_LOG_SUCCESS)
  {
    /* Place your code here to handle an initialization error */
  }

  for (;;)
  {
    /* Main watchdog service */
    (void) PMU_serviceFailSafeWatchdog();

    u32_tick++;
    if (u32_tick > 100000)
    {
      GPIO_setP02State(GPIO_STATE_TOGGLE);
      u32_tick = 0;
    }
  }
}


/* user-defined call back function for rising edge on MON2 pin */
__attribute__((__noreturn__))void MON2_RI_Int(void)
{
  /* Reset device to start execution from bootloader again */
  __NVIC_SystemReset();
}
