/*
 ***********************************************************************************************************************
 *
 * Copyright (c) Infineon Technologies AG
 * All rights reserved.
 *
 * The applicable license agreement can be found at this pack's installation directory in the file
 * license/IFX_SW_Licence_MOTIX_LITIX.txt
 *
 **********************************************************************************************************************/

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** BG           Blandine Guillot                                              **
** JO           Julia Ott                                                     **
** EE           Erich Englbrecht                                              **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V1.0.0: 2021-03-01, EE:   EP-711: Initial version                          **
** V1.0.1: 2021-10-06, JO:   EP-949: Corrected memory layout (IROM1 size,     **
**                           IRAM1 start and size, IRAM2 size)                **
** V1.0.2: 2021-10-15, JO:   EP-962: Updated NAC time                         **
** V1.0.3: 2021-10-22, BG:   EP-814: Added return code for TLE_init()         **
**                           Removed clearing of status registers, should be  **
**                           done in the init functions if they are passed    **
** V1.0.4: 2021-11-11, JO:   EP-937: Updated copyright and branding           **
** V1.0.5: 2021-12-20, JO:   EP-977: Added '--diag_suppress 1609' to Asm Misc **
**                           Control to remove compiler warning               **
** V1.1.0: 2023-04-18, JO:   EP-1235: Changed to C startup file               **
** V1.2.0: 2024-06-14, JO:   EP-1480: Disabled  warning 'unsafe buffer usage' **
**                           (ARM compiler for Embedded version >6.21)        **
** V1.2.1: 2024-10-04, JO:   EP-1494: Updated license                         **
** V1.3.0: 2024-12-04, JO:   EP-1553: Add all drivers to the example in RTE   **
*******************************************************************************/

/*******************************************************************************
**                                  Abstract                                  **
********************************************************************************
** PMU: Sleep mode, wake-up with MON1                                         **
********************************************************************************
** When GPIO pin 0.1 is set to high, the system enters the sleep mode.        **
** The system leaves the sleep mode when the MON1 button (wakeup trigger) is  **
** pressed.                                                                   **
** During normal operation the LED 0.2 is on. When the system is in the sleep **
** mode the LED 0.2 is off.                                                   **
*******************************************************************************/

/*******************************************************************************
**                                  Includes                                  **
*******************************************************************************/
#include "tle_device.h"
#include "types.h"
#include "gpio.h"
#include "pmu.h"

/*******************************************************************************
**                                 Constants                                  **
*******************************************************************************/
#define GPIO_P01_HIGH (0x1U)


sint32 main(void)
{
  sint8 s8_returnCode;

  /* Clear Watchdog fail status */
  PMU_clrFailSafeWatchdogFailSts();

   /* Initialization of hardware modules based on Config Wizard configuration. */
  s8_returnCode = TLE_init();
  
  if (s8_returnCode != ERR_LOG_SUCCESS)
  {
    /* Place your code here to handle an initialization error */
  }

  for (;;)
  {
    /* Main watchdog service */
    (void) PMU_serviceFailSafeWatchdog();
    
    /* Check if GPIO 0.1 is high. */
    if (GPIO_P01_HIGH == GPIO_getP01State())
    {
      /* Enter sleep mode */
      SCU_enterSleepMode();
    }
    else
    {
      /* If the CPU is not in sleep mode, set GPIO 0.2 to high. */
      GPIO_setP02State(GPIO_STATE_HIGH);
    }
  }
}
