/*
 ***********************************************************************************************************************
 *
 * Copyright (c) Infineon Technologies AG
 * All rights reserved.
 *
 * The applicable license agreement can be found at this pack's installation directory in the file
 * license/IFX_SW_Licence_MOTIX_LITIX.txt
 *
 **********************************************************************************************************************/

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** AA           Abhilash Abhilash                                             **
** JO           Julia Ott                                                     **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V1.0.0: 2020-10-21, AA:   EP-923: Initial version                          **
** V1.0.1: 2024-10-04, JO:   EP-1494: Updated license                         **
*******************************************************************************/

#ifndef _SECURITY_ACCESS_H
#define _SECURITY_ACCESS_H

/*******************************************************************************
**                                  Includes                                  **
*******************************************************************************/
#include "types.h"
#include "bootrom.h"

/*******************************************************************************
**                          Global Macro Declarations                         **
*******************************************************************************/
/** \brief IO buffer size */ 
#define TLE989X_AES_IO_BUFFER_SIZE (32u)

/** \brief Subfunction for SEED request */
#define SEED_REQUEST (0x01u)

/** \brief Subfunction for KEY request */
#define KEY_REQUEST (0x02u)

/** \brief Message length */              
#define REQUEST_LENGTH (34u)

/** \brief Key slot to be used for encryption. Key slot '0' is reserved. */
#define KEY_ID (1u)

/** \brief Invalid key, NRC*/ 
#define WRONG_KEY (0x35u)    

/** \brief Incorrect subfunction, NRC */                   
#define SUBFUNC_ERROR (0x12u)     

/** \brief Incorrect sequence, NRC */ 
#define SEQUENCE_ERROR (0x24u)     

/** \brief Incorrect length, NRC */ 
#define LENGTH_ERROR (0x13u)     

/** \brief Service not supported, NRC */
#define SERVICE_NOT_SUPPORTED (0x11u)     

/** \brief +ve response indication byte for security access (0x27 + 0x40) */ 
#define POS_RESP_ID (0x67u)     

/** \brief -ve response indication byte */ 
#define NEG_RESP_ID (0x7Fu)     

/** \brief +ve response length*/ 
#define POS_RESP_LENGTH (0x02u)     

/** \brief -ve response length*/ 
#define NEG_RESP_LENGTH (0x03u)     

/** \brief Request ID */ 
#define SECURITY_ACCESS_REQ_SERVICE_ID (0x27u)          

/** \brief Update length used for encryption or decryption */
#define AES_UPDATE_LENGTH (32u)      

/** \brief offset value */
#define OFFSET_LENGTH (8u) 
      
/*******************************************************************************
**                          Global Type Declarations                          **
*******************************************************************************/

/** \struct tDiagMsg
 *  \brief This struct lists the parameters for the diagnostic request and response message
 */
typedef struct DiagMsg
{
  uint8  u8_req[TLE989X_AES_IO_BUFFER_SIZE + OFFSET_LENGTH];   /** \brief Request message buffer */ 
  uint32 u32_reqLength;                                        /** \brief Request message length */ 
  uint8  u8_resp[TLE989X_AES_IO_BUFFER_SIZE];                  /** \brief Response message buffer */ 
  uint32 u32_respLength;                                       /** \brief Response message buffer */ 
} tDiagMsg;


/*******************************************************************************
**                        Global Function Declarations                        **
*******************************************************************************/

void serviceSecurityAccess(tDiagMsg *sp_msg);

#endif  /* _SECURUTY_ACCESS_H  */

