/*
 ***********************************************************************************************************************
 *
 * Copyright (c) Infineon Technologies AG
 * All rights reserved.
 *
 * The applicable license agreement can be found at this pack's installation directory in the file
 * license/IFX_SW_Licence_MOTIX_LITIX.txt
 *
 **********************************************************************************************************************/

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** CK           Chander Kumar                                                 **
** JO           Julia Ott                                                     **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V0.0.1: 2022-08-18, CK:   EP-1241: Initial version                         **
** V1.1.0: 2023-04-18, JO:   EP-1235: Changed to C startup file               **
** V1.2.0: 2024-06-14, JO:   EP-1480: Disabled  warning 'unsafe buffer usage' **
**                           (ARM compiler for Embedded version >6.21)        **
** V1.2.1: 2024-10-04, JO:   EP-1494: Updated license                         **
** V1.3.0: 2024-12-04, JO:   EP-1553: Add all drivers to the example in RTE   **
*******************************************************************************/

/*******************************************************************************
**                                  Abstract                                  **
********************************************************************************
** T20: Capturing a PWM signal via T20                                        **
********************************************************************************
** The timer T20 used to capture a PWM signal at GPIO P0.3.                   **
** The measured ticks (low phase, period) are stored in the static variables  **
** capDC and capPer.                                                          **
*******************************************************************************/

/*******************************************************************************
**                                  Includes                                  **
*******************************************************************************/
#include "tle_device.h"
#include "types.h"

/*******************************************************************************
**                                 Variables                                  **
*******************************************************************************/
static uint16 capPer, capDC;
static uint16 bDC_Per;

/*******************************************************************************
**                           Function Declarations                            **
*******************************************************************************/
void PWM_Capture(void);


sint32 main(void)
{
  sint8 s8_returnCode;
  
  /* Clear watchdog fail status */
  PMU_clrFailSafeWatchdogFailSts();
  
  /* Initialization of hardware modules based on Config Wizard configuration */
  s8_returnCode = TLE_init();
  
  if (s8_returnCode != ERR_LOG_SUCCESS)
  {
    /* Place your code here to handle an initialization error */
  }
  
  bDC_Per = 0;
	
  /*****************************************************************************
  ** Main endless loop                                                        **
  *****************************************************************************/
  for (;;)
  {
    /* Main watchdog service */
    (void)PMU_serviceFailSafeWatchdog();    
    
  }
}


/* Callback function for Timer2 */
void PWM_Capture(void)
{
  /* Timer20 in run mode */
  if(T20->CON.bit.TR2 == 1)
  {
    if (bDC_Per == 0u)
    {
      /* Get the duty cycle */
      capDC = T20_getCapRelVal();
      /* Next capture on falling edge */
      T20->MOD.bit.EDGESEL = 0u;
      bDC_Per = 1u;
    }
    else
    {
      /* Get the PWM period */
      capPer = T20_getCapRelVal();
      /* Next capture on rising edge */
      T20->MOD.bit.EDGESEL = 1u;
      bDC_Per = 0u;
      /* Stop Timer20 */
      T20_stop();
      /* Reset Timer20 */
      T20_setCntVal(0);
    }
  }
}
