/*
 ***********************************************************************************************************************
 *
 * Copyright (c) Infineon Technologies AG
 * All rights reserved.
 *
 * The applicable license agreement can be found at this pack's installation directory in the file
 * license/IFX_SW_Licence_MOTIX_LITIX.txt
 *
 **********************************************************************************************************************/

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** BG           Blandine Guillot                                              **
** JO           Julia Ott                                                     **
** EE           Erich Englbrecht                                              *
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V1.0.0: 2020-04-28, EE:   EP-676: Initial version                          **
** V1.0.1: 2021-07-27, BG:   EP-814: Added return code for TLE_init()         **
**                           Removed clearing of status registers, should be  **
**                           done in the init functions if they are passed    **
** V1.0.2: 2021-10-06, JO:   EP-949: Corrected memory layout (IROM1 size,     **
**                           IRAM1 start and size, IRAM2 size)                **
** V1.0.3: 2021-10-15, JO:   EP-962: Updated NAC time                         **
** V1.0.4: 2021-11-11, JO:   EP-937: Updated copyright and branding           **
** V1.0.5: 2021-12-20, JO:   EP-977: Added '--diag_suppress 1609' to Asm Misc **
**                           Control to remove compiler warning               **
** V1.1.0: 2023-04-18, JO:   EP-1235: Changed to C startup file               **
** V1.2.0: 2024-06-14, JO:   EP-1480: Disabled warning 'unsafe buffer usage'  **
**                           (ARM compiler for Embedded version >6.21)        **
** V1.2.1: 2024-10-04, JO:   EP-1494: Updated license                         **
** V1.3.0: 2024-12-04, JO:   EP-1553: Add all drivers to the example in RTE   **
*******************************************************************************/

/*******************************************************************************
**                                  Abstract                                  **
********************************************************************************
** UART: Using printf to write via UART debug pin                             **
********************************************************************************
** A string HelloWorld is written to the standard output.                     **
** A user-defined stdout target is implemented in the uart module.            **
** The redirection is established via compiler-I/O-STDOUT RTE setting.        **
** The pin P1.1 is used as output which is the debug pin on the USB device.   **
*******************************************************************************/

/*******************************************************************************
**                                  Includes                                  **
*******************************************************************************/
#include <stdio.h>
#include "tle_device.h"
#include "types.h"


sint32 main(void)
{
  sint8 s8_returnCode;
  
  /* Clear watchdog fail status */
  PMU_clrFailSafeWatchdogFailSts();

  /* Initialization of hardware modules based on Config Wizard configuration */
  s8_returnCode = TLE_init();
  
  if (s8_returnCode != ERR_LOG_SUCCESS)
  {
    /* Place your code here to handle an initialization error */
  }

  /* Print HelloWorld to the stdout */
  printf("HelloWorld");

  for (;;)
  {
    /* Main watchdog service */
    (void) PMU_serviceFailSafeWatchdog();
  }
}
