/*
 ***********************************************************************************************************************
 *
 * Copyright (c) Infineon Technologies AG
 * All rights reserved.
 *
 * The applicable license agreement can be found at this pack's installation directory in the file
 * license/IFX_SW_Licence_MOTIX_LITIX.txt
 *
 **********************************************************************************************************************/

/**
 * \file     main.c
 *
 * \brief    Template for main.c
 *
 * \version  V1.5.6
 * \date     05. Nov 2024
 *
 * \note
 */

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** DM           Daniel Mysliwitz                                              **
** BG           Blandine Guillot                                              **
** JO           Julia Ott                                                     **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V1.5.0: 2015-08-07, BG:   Initial version for TLE989x                      **
** V1.5.1: 2020-12-18, BG:   EP-652: Corrected name of error code variable    **
**                           clear Watchdog fail status                       **
**                           clear fail safe status flags                     **
**                           clear bridge driver status flags                 **
** V1.5.2: 2021-02-03, JO:   EP-684: Fixed MISRA violations in main.c file    **
** V1.5.3: 2021-03-08, BG:   EP-733: Updated comments                         **
**                           Removed FIFO pull-up enable to put it in PMU_init**
** V1.5.4: 2021-07-27, BG:   EP-814: Added return code for TLE_init()         **
**                           Removed clearing of status registers, should be  **
**                           done in the init functions if they are passed    **
** V1.5.5: 2021-11-11, JO:   EP-937: Updated copyright and branding           **
** V1.5.6: 2024-11-05, JO:   EP-1494: Updated license                         **
*******************************************************************************/

/*******************************************************************************
**                                  Includes                                  **
*******************************************************************************/
#include "tle_device.h"
#include "types.h"

/*******************************************************************************
**                        Global Constant Declarations                        **
*******************************************************************************/

/*******************************************************************************
**                          Global Type Declarations                          **
*******************************************************************************/

/*******************************************************************************
**                          Global Macro Declarations                         **
*******************************************************************************/

/*******************************************************************************
**                        Global Function Declarations                        **
*******************************************************************************/

/*******************************************************************************
**                     Global Inline Function Definitions                     **
*******************************************************************************/

sint32 main(void)
{
  sint8 s8_returnCode;
  /* Clear watchdog fail status */
  PMU_clrFailSafeWatchdogFailSts();
  /* Initialization of hardware modules based on Config Wizard configuration */
  s8_returnCode = TLE_init();

  if (s8_returnCode != ERR_LOG_SUCCESS)
  {
    /* Place your code here to handle an initialization error */
  }

  /*****************************************************************************
  ** Place your application code here                                         **
  *****************************************************************************/

  /*****************************************************************************
  ** Main endless loop                                                        **
  *****************************************************************************/
  for (;;)
  {
    /* Main watchdog service */
    (void)PMU_serviceFailSafeWatchdog();
    /***************************************************************************
    ** Place your application code here                                       **
    ***************************************************************************/
  }
}

